package org.rcisoft.business.device.service.impl;

import org.rcisoft.business.device.dao.BusDeviceRepository;
import org.rcisoft.business.device.service.BusDeviceService;
import org.rcisoft.business.device.vo.DeviceAssetStatisticVo;
import org.rcisoft.core.aop.PageUtil;
import org.rcisoft.core.model.PersistModel;
import org.rcisoft.business.device.entity.BusDevice;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;


import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by  on 2018-4-12 15:33:23.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BusDeviceServiceImpl implements BusDeviceService {

    @Autowired
    private BusDeviceRepository busDeviceRepository;


    /**
    * 保存 busDevice
    * @param busDevice
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel save(BusDevice busDevice){
        //增加操作
//        UserUtil.setCurrentPersistOperation(busDevice);
        int line = busDeviceRepository.insertSelective(busDevice);
        return new PersistModel(line);
    }

    /**
    * 逻辑删除
    * @param busDevice
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel remove(BusDevice busDevice){
//        UserUtil.setCurrentMergeOperation(busDevice);
//        busDevice.setDeleted();
        int line = busDeviceRepository.logicalDelete(busDevice);
        return new PersistModel(line);
    }

    /**
    * 修改 busDevice
    * @param busDevice
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel merge(BusDevice busDevice){
//        UserUtil.setCurrentMergeOperation(busDevice);
        int line = busDeviceRepository.updateByPrimaryKeySelective(busDevice);
        return new PersistModel(line);
    }

    /**
    * 根据id查询 busDevice
    * @param id
    * @return
    */
    @Override
    public BusDevice findById(String id)
    {
        return busDeviceRepository.selectByPrimaryKey(id);
    }

    /**
    * 分页查询 busDevice
    * @param busDevice
    * @return
    */
    @Override
    public List<BusDevice> findAllByPagination(PageUtil<BusDevice> paginationUtility,
                                               BusDevice busDevice){
//        busDevice.setStart();
//        busDevice.setNotDeleted();
        return busDeviceRepository.queryBusDevices(busDevice);
    }
    /*
        通过项目id与子系统id获取子系统中的所有设备
        @param sysId  子系统id
        @param proId  项目id
         */
    @Override
    public List<DeviceAssetStatisticVo> getDevicesBySysId(String sysId, String proId) {
        return busDeviceRepository.getBusDevicesBySysId(sysId,proId);
    }

    @Override
    public String getProNameByProId(String proId) {
        return busDeviceRepository.getProNameByProId(proId);
    }

    @Override
    public String getSysNameBySysId(String sysId) {
        return busDeviceRepository.getSysNameBySysId(sysId);
    }
}
